A struct that keeps information about the test.
It is received by formatters and contains the following fields:
:name- the test name. This is the function name in the test module, which is truncated and hashed when above 250 characters:module- the test module:description- the test description (the name without truncation):state- the finished test state (seeExUnit.state/0):time- the duration in microseconds of the test's runtime:tags- the test tags:logs- the captured logs:parameters- the test parameters
Summary
Types
@type t() :: %ExUnit.Test{ case: module(), description: String.t(), logs: String.t(), module: module(), name: atom(), parameters: map(), state: ExUnit.state(), tags: map(), time: non_neg_integer() }